@@ -23,10 +23,3 @@ impl Display for MssqlTypeInfo {
     }
 }
 
-#[cfg(feature = "any")]
-impl From<MssqlTypeInfo> for crate::any::AnyTypeInfo {
-    #[inline]
-    fn from(ty: MssqlTypeInfo) -> Self {
-        crate::any::AnyTypeInfo(crate::any::type_info::AnyTypeInfoKind::Mssql(ty))
-    }
-}
